==> s-render-0.4.3.tgz: package/lib/FormRender/RenderCore/FieldItem/Main.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/FormRender/RenderCore/FieldItem/Main.tsx
var Main_exports = {};
__export(Main_exports, {
  default: () => Main_default
});
module.exports = __toCommonJS(Main_exports);
var import_antd = require("antd");
var import_react = require("react");
var import_zustand = require("zustand");
var import_context = require("../../models/context");
var import_validates = __toESM(require("../../models/validates"));
var valuePropNameMap = {
  Boolean: "checked"
};
var Main_default = (props) => {
  const { schema, path, dependValues, tableInline } = props;
  const configCtx = (0, import_react.useContext)(import_context.ConfigContext);
  const formRenderContext = (0, import_react.useContext)(import_context.FormRenderContext);
  const { readOnly } = (0, import_zustand.useStore)(
    formRenderContext,
    (state) => state == null ? void 0 : state.context
  );
  const { form, widgets, globalConfig, methods, globalRules } = configCtx;
  const { type, title, list, valueType, businessType, hidden } = schema;
  if (type === "Form" && !list) {
    if (hidden)
      return null;
    const Widget2 = widgets["boxCard"];
    return /* @__PURE__ */ React.createElement(import_antd.Col, { span: 24, style: { marginBottom: "24px" } }, /* @__PURE__ */ React.createElement(Widget2, { ...props }));
  }
  const mergeReadOnly = (schema == null ? void 0 : schema.readOnly) ?? readOnly;
  const textWidget = type === "Text" ? "Text" : "ReadOnlyText";
  const Widget = widgets[mergeReadOnly ? textWidget : businessType ?? valueType ?? type];
  const defaultValue = schema.default ?? schema.defaultValue;
  if (businessType === "mainDataRender") {
    console.log(Widget, "ssss");
  }
  const ruleList = (0, import_validates.default)(schema, form, methods);
  const valuePropName = schema.valuePropName || valuePropNameMap[valueType ?? type] || void 0;
  const span = (schema == null ? void 0 : schema.span) || (globalConfig == null ? void 0 : globalConfig.span) || 3;
  const Component = (0, import_react.useMemo)(() => {
    return Widget({
      placeholder: title,
      schema,
      dependValues,
      disabled: schema == null ? void 0 : schema.disabled
    });
  }, [
    title,
    JSON.stringify(schema),
    JSON.stringify(dependValues),
    tableInline,
    span,
    hidden,
    businessType,
    valueType,
    type,
    textWidget,
    mergeReadOnly
  ]);
  return /* @__PURE__ */ React.createElement(import_antd.Col, { span: hidden ? 0 : tableInline ? 24 : 24 / span }, /* @__PURE__ */ React.createElement(
    import_antd.Form.Item,
    {
      label: tableInline ? "" : title,
      colon: !tableInline,
      style: tableInline && {
        marginBottom: 0
      } || {},
      name: path,
      hidden,
      initialValue: (valueType ?? type) === "Boolean" ? false : defaultValue,
      valuePropName,
      rules: ruleList
    },
    Component
  ));
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});

==> s-render-0.4.9.tgz: package/lib/FormRender/RenderCore/FieldItem/Main.js <==
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/FormRender/RenderCore/FieldItem/Main.tsx
var Main_exports = {};
__export(Main_exports, {
  default: () => Main_default
});
module.exports = __toCommonJS(Main_exports);
var import_antd = require("antd");
var import_react = require("react");
var import_zustand = require("zustand");
var import_context = require("../../models/context");
var import_validates = __toESM(require("../../models/validates"));
var valuePropNameMap = {
  Boolean: "checked"
};
var Main_default = (props) => {
  const { schema, path, dependValues, tableInline } = props;
  const configCtx = (0, import_react.useContext)(import_context.ConfigContext);
  const formRenderContext = (0, import_react.useContext)(import_context.FormRenderContext);
  const { readOnly } = (0, import_zustand.useStore)(
    formRenderContext,
    (state) => state == null ? void 0 : state.context
  );
  const { form, widgets, globalConfig, methods, globalRules } = configCtx;
  const { type, title, list, valueType, businessType, hidden } = schema;
  if (type === "Form" && !list) {
    if (hidden)
      return null;
    const Widget2 = widgets["boxCard"];
    return /* @__PURE__ */ React.createElement(import_antd.Col, { span: 24, style: { marginBottom: "24px" } }, /* @__PURE__ */ React.createElement(Widget2, { ...props }));
  }
  const mergeReadOnly = (schema == null ? void 0 : schema.readOnly) ?? readOnly;
  const textWidget = type === "Text" ? "Text" : "ReadOnlyText";
  const widgetName = mergeReadOnly ? textWidget : businessType ?? valueType ?? type;
  const Widget = widgets[widgetName];
  const defaultValue = schema.default ?? schema.defaultValue;
  const ruleList = (0, import_validates.default)(schema, form, methods);
  const valuePropName = schema.valuePropName || valuePropNameMap[valueType ?? type] || void 0;
  const span = (schema == null ? void 0 : schema.span) || (globalConfig == null ? void 0 : globalConfig.span) || 3;
  const Component = (0, import_react.useMemo)(() => {
    return Widget({
      placeholder: title,
      schema,
      dependValues,
      disabled: schema == null ? void 0 : schema.disabled
    });
  }, [
    title,
    JSON.stringify(schema),
    JSON.stringify(dependValues),
    tableInline,
    span,
    hidden,
    widgetName
  ]);
  return /* @__PURE__ */ React.createElement(import_antd.Col, { span: hidden ? 0 : tableInline ? 24 : 24 / span }, /* @__PURE__ */ React.createElement(
    import_antd.Form.Item,
    {
      label: tableInline ? "" : title,
      colon: !tableInline,
      style: tableInline && {
        marginBottom: 0
      } || {},
      name: path,
      hidden,
      initialValue: (valueType ?? type) === "Boolean" ? false : defaultValue,
      valuePropName,
      rules: ruleList
    },
    Component
  ));
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
